var group__KERNEL__DPL__EVENT =
[
    [ "EventP_construct", "group__KERNEL__DPL__EVENT.html#gafca8272287bdaa6a6e5cc7b29f52105e", null ],
    [ "EventP_destruct", "group__KERNEL__DPL__EVENT.html#gae4b3c278316a067d41e141591630e594", null ],
    [ "EventP_waitBits", "group__KERNEL__DPL__EVENT.html#ga49665ab39513aebef09c689c6e1c34cd", null ],
    [ "EventP_setBits", "group__KERNEL__DPL__EVENT.html#ga3ebf3093b25a2a3036ef20f5224c69cc", null ],
    [ "EventP_clearBits", "group__KERNEL__DPL__EVENT.html#ga1862bf85d3f7e9ff0dfafa22e2da2fe4", null ],
    [ "EventP_getBits", "group__KERNEL__DPL__EVENT.html#gafc3f4a27c2889586c62ad25508f86275", null ]
];